@@ -1,5 +1,6 @@
-from datetime import date, datetime, timedelta, time
+import datetime
 from calendar import month_name
+
 try:
     # < 3.0
     from celery.log import get_task_logger
@@ -12,32 +13,49 @@ from dimagi.utils.logging import log_exception
 from dimagi.utils.parsing import string_to_datetime
 from dateutil.rrule import *
 
+
 def force_to_date(val):
     """Forces a date, string, or datetime to a date."""
-    if not val:                      return val
-    if isinstance(val, datetime):    return val.date()
-    if isinstance(val, date):        return val
-    if isinstance(val, basestring):  return string_to_datetime(val).date()
-    else:                            raise ValueError("object must be date or datetime!")
-    
+    if not val:
+        return val
+    elif isinstance(val, datetime.datetime):
+        return val.date()
+    elif isinstance(val, datetime.date):
+        return val
+    elif isinstance(val, basestring):
+        return string_to_datetime(val).date()
+    else:
+        raise ValueError("object must be date or datetime!")
+
+
 def force_to_datetime(val):
     """Forces a date, string, or datetime to a datetime."""
-    if not val:                        return val
-    elif isinstance(val, datetime):    return val
-    elif isinstance(val, date):        return datetime.combine(val, time())
-    elif isinstance(val, basestring):  return string_to_datetime(val)
-    else:                              raise ValueError("object must be date or datetime!")    
-        
+    if not val:
+        return val
+    elif isinstance(val, datetime.datetime):
+        return val
+    elif isinstance(val, datetime.date):
+        return datetime.datetime.combine(val, datetime.time())
+    elif isinstance(val, basestring):
+        return string_to_datetime(val)
+    else:
+        raise ValueError("object must be date or datetime!")
+
+
 def safe_date_add(startdate, days, force_to_date_flag=True):
-    if not startdate:  return None
+    if not startdate:
+        return None
     try: 
-        val = startdate + timedelta(days)
-        if force_to_date_flag:  return force_to_date(val)
-        else:                   return val 
+        val = startdate + datetime.timedelta(days)
+        if force_to_date_flag:
+            return force_to_date(val)
+        else:
+            return val
     except OverflowError, e:
         log_exception(e) 
         return None
 
+
 def months_between(start, end):
     """
     Given a start date and enddate return all months between them.
@@ -50,42 +68,51 @@ def months_between(start, end):
     while start <= end:
         months.append((start.year, start.month))
         (yearnext, monthnext) = add_months(start.year, start.month, 1)
-        start = datetime(yearnext, monthnext, 1)
+        start = datetime.datetime(yearnext, monthnext, 1)
     return months        
 
+
 def add_months(year, months, offset):
     """
     Add a number of months to the passed in year and month, returning
     a tuple of (year, month)
     """
-    months = months - 1 # 0 index months coming in
+    months = months - 1  # 0 index months coming in
     nextmonths = months + offset
-    months_offset = nextmonths % 12 + 1 # 1 index it going out
+    months_offset = nextmonths % 12 + 1  # 1 index it going out
     years_offset = nextmonths / 12
     return (year + years_offset, months_offset)
 
+
 def first_of_next_month(ref_date):
     """
     Given a datetime, return a datetime that is the first of the following
     month.
     """
     year, month = add_months(ref_date.year, ref_date.month, 1)
-    return datetime(year, month, 1)
+    return datetime.datetime(year, month, 1)
+
 
 def delta_secs(td):
     """convert a timedelta to seconds"""
     return 86400. * td.days + td.seconds + 1.0e-6 * td.microseconds
 
+
 def secs_to_days(seconds):
     """convert a number of seconds to days"""
     return float(seconds) / 86400. 
 
 
 def utcnow_sans_milliseconds():
-    return datetime.utcnow().replace(microsecond=0)
+    return datetime.datetime.utcnow().replace(microsecond=0)
     
 DEFAULT_DATE_FORMAT = "%Y-%m-%d"
-    
+
+def today_or_tomorrow(date, inclusive=True):
+    today = datetime.datetime.combine(datetime.datetime.today(), datetime.time())
+    day_after_tomorrow = today + datetime.timedelta(days=2)
+    return today <= date + datetime.timedelta(days=1 if inclusive else 0) < day_after_tomorrow
+
 class DateSpan(object):
     """
     A useful class for representing a date span
@@ -95,7 +122,7 @@ class DateSpan(object):
     format = None
     inclusive = True
     is_default = False
-    
+
     def __init__(self, startdate, enddate, format=DEFAULT_DATE_FORMAT, inclusive=True, timezone=pytz.utc):
         self.startdate = startdate
         self.enddate = enddate
@@ -162,7 +189,7 @@ class DateSpan(object):
         """
         if self.enddate:
             # you need to add a day to enddate if your dates are meant to be inclusive
-            offset = timedelta(days=1 if self.inclusive else 0)
+            offset = datetime.timedelta(days=1 if self.inclusive else 0)
             return (self.enddate + offset)
         
     
@@ -205,7 +232,7 @@ class DateSpan(object):
     def enddate_param(self):
         if self.enddate:
             # you need to add a day to enddate if your dates are meant to be inclusive
-            offset = timedelta(days=1 if self.inclusive else 0)
+            offset = datetime.timedelta(days=1 if self.inclusive else 0)
             return (self.enddate + offset).strftime(self.format)
 
     @property
@@ -213,7 +240,7 @@ class DateSpan(object):
         if self.enddate:
             adjusted_enddate = self.adjust_to_utc(self.enddate)
             # you need to add a day to enddate if your dates are meant to be inclusive
-            adjusted_enddate = (adjusted_enddate + timedelta(days=1 if self.inclusive else 0))
+            adjusted_enddate = (adjusted_enddate + datetime.timedelta(days=1 if self.inclusive else 0))
             return adjusted_enddate
 
     @property
@@ -231,7 +258,7 @@ class DateSpan(object):
     def adjust_to_utc(self, date):
         localized = self.timezone.localize(date)
         offset = localized.strftime("%z")
-        return date - timedelta(hours=int(offset[0:3]), minutes=int(offset[0] + offset[3:5]))
+        return date - datetime.timedelta(hours=int(offset[0:3]), minutes=int(offset[0] + offset[3:5]))
 
     @property
     def end_of_end_day(self):
@@ -265,27 +292,15 @@ class DateSpan(object):
             return "Invalid date span %s - %s" % (self.startdate_param, self.enddate_param)
 
         # if the dates comprise a month exactly, use that
-        if self.startdate.day == 1 and (self.enddate + timedelta(days=1)).day == 1:
+        if self.startdate.day == 1 and (self.enddate + datetime.timedelta(days=1)).day == 1:
             return "%s %s" % (month_name[self.startdate.month], self.startdate.year)
 
-        # if the end date is today or tomorrow, use "last N days syntax"  
-        today = datetime.combine(datetime.today(), time())
-        day_after_tomorrow = today + timedelta(days=2)
-        if today <= self.enddate + timedelta(days=(1 if self.inclusive else 0)) < day_after_tomorrow:
+        # if the end date is today or tomorrow, use "last N days syntax"
+        if today_or_tomorrow(self.enddate, self.inclusive):
             return "last %s days" % ((self.enddate - self.startdate).days + (1 if self.inclusive else 0))
         
         return "%s to %s" % (self.startdate.strftime(self.format), 
                              self.enddate.strftime(self.format))
-        
-    @classmethod
-    def month(cls, year, month, format=DEFAULT_DATE_FORMAT):
-        """
-        Generate a datespan covering a month.
-        """
-        start = datetime(year, month, 1)
-        nextmonth = start + timedelta(days=32)
-        end = datetime(nextmonth.year, nextmonth.month, 1) - timedelta(milliseconds=1)
-        return DateSpan(start, end, format)
 
     @classmethod
     def since(cls, days, enddate=None, format=DEFAULT_DATE_FORMAT, inclusive=True, timezone=pytz.utc):
@@ -303,15 +318,15 @@ class DateSpan(object):
         Will always ignore times.
         """
         if enddate is None:
-            enddate = datetime.now(tz=timezone)
+            enddate = datetime.datetime.now(tz=timezone)
             if inclusive:
-                enddate = enddate - timedelta(days=1)
+                enddate = enddate - datetime.timedelta(days=1)
 
         if inclusive:
             days += -1
 
-        end = datetime(enddate.year, enddate.month, enddate.day)
-        start = end - timedelta(days=days)
+        end = datetime.datetime(enddate.year, enddate.month, enddate.day)
+        start = end - datetime.timedelta(days=days)
         return DateSpan(start, end, format, inclusive, timezone)
 
 
@@ -323,25 +338,12 @@ class DateSpan(object):
             display_format = format
         
         def date_or_nothing(param):
-            return datetime.strptime(dict[param], parse_format)\
+            return datetime.datetime.strptime(dict[param], parse_format)\
                         if param in dict and dict[param] else None
         startdate = date_or_nothing(startdate_str)
         enddate = date_or_nothing(enddate_str)
         return DateSpan(startdate, enddate, format)
 
-    def months_iterator(self):
-        """
-        Iterate over (year, month) pairs (inclusive) in this datespan.
-        """
-        for year in range(self.startdate.year, self.enddate.year + 1):
-            startmonth = 1
-            endmonth = 12
-            if year == int(self.startdate.year):
-                startmonth = self.startdate.month
-            if year == int(self.enddate.year):
-                endmonth = self.enddate.month
-            for month in range(startmonth, endmonth + 1):
-                yield (year, month)
 
 def is_business_day(day):
     """
@@ -357,7 +359,7 @@ def get_day_of_month(year, month, count):
     just creating the date object is to support negative numbers
     e.g. pass in -1 for "last"
     """
-    r = rrule(MONTHLY, dtstart=datetime(year,month, 1),
+    r = rrule(MONTHLY, dtstart=datetime.datetime(year,month, 1),
               byweekday=(MO, TU, WE, TH, FR, SA, SU),
               bysetpos=count)
     res = r[0]
@@ -371,7 +373,7 @@ def get_business_day_of_month(year, month, count):
     Count can also be negative, e.g. pass in -1 for "last"
     """
     r = rrule(MONTHLY, byweekday=(MO, TU, WE, TH, FR), 
-              dtstart=datetime(year,month, 1),
+              dtstart=datetime.datetime(year,month, 1),
               bysetpos=count)
     res = r[0]
     if (res == None or res.month != month or res.year != year):
@@ -384,17 +386,17 @@ def get_business_day_of_month_after(year, month, day):
     that falls on or after the passed in day
     """
     try:
-        adate = datetime(year, month, day)
+        adate = datetime.datetime(year, month, day)
     except ValueError:
         try:
-            adate = datetime(year, month, 30)
+            adate = datetime.datetime(year, month, 30)
         except ValueError:
             try:
-                adate = datetime(year, month, 29)
+                adate = datetime.datetime(year, month, 29)
             except ValueError:
-                adate = datetime(year, month, 28)
+                adate = datetime.datetime(year, month, 28)
     r = rrule(MONTHLY, byweekday=(MO, TU, WE, TH, FR), 
-              dtstart=datetime(year,month, 1))
+              dtstart=datetime.datetime(year,month, 1))
     res = r.after(adate, inc=True)
     if (res == None or res.month != month or res.year != year):
         raise ValueError("No dates found in range. is there a flaw in your logic?")
@@ -406,17 +408,17 @@ def get_business_day_of_month_before(year, month, day):
     that falls on or before the passed in day
     """
     try:
-        adate = datetime(year, month, day)
+        adate = datetime.datetime(year, month, day)
     except ValueError:
         try:
-            adate = datetime(year, month, 30)
+            adate = datetime.datetime(year, month, 30)
         except ValueError:
             try:
-                adate = datetime(year, month, 29)
+                adate = datetime.datetime(year, month, 29)
             except ValueError:
-                adate = datetime(year, month, 28)
+                adate = datetime.datetime(year, month, 28)
     r = rrule(MONTHLY, byweekday=(MO, TU, WE, TH, FR), 
-              dtstart=datetime(year,month,1))
+              dtstart=datetime.datetime(year,month,1))
     res = r.before(adate, inc=True)
     if (res == None or res.month != month or res.year != year):
         raise ValueError("No dates found in range. is there a flaw in your logic?")
